from clients.base_client import BaseAPIClient
from models.meta_responses import (
    GameTypeAPIResponse,
    SeasonAPIResponce,
    TierAPIResponse,
)


class OPGGMetaClient(BaseAPIClient):
    def __init__(self) -> None:
        super().__init__(base_url="https://lol-api-summoner.op.gg/api/meta/")

    def get_seasons(self) -> SeasonAPIResponce:
        endpoint = f"seasons"
        params = {"hl": "eu_US"}

        return SeasonAPIResponce(**self._get(endpoint, params).json())

    def get_tiers(self) -> TierAPIResponse:
        endpoint = f"tiers"
        params = {"hl": "eu_US"}

        return TierAPIResponse(**self._get(endpoint, params).json())

    def get_game_types(self) -> GameTypeAPIResponse:
        endpoint = f"game-type"
        params = {"hl": "eu_US"}

        return GameTypeAPIResponse(**self._get(endpoint, params).json())



from typing import Optional

from pydantic import BaseModel

from models.base_model import BaseResponse


class EvolveItem(BaseModel):
    key: str
    name: str
    image_url: str


class Info(BaseModel):
    attack: float
    defense: float
    magic: float
    difficulty: float


class Stats(BaseModel):
    hp: float
    hpperlevel: float
    mp: float
    mpperlevel: float
    movespeed: float
    armor: float
    armorperlevel: float
    spellblock: float
    spellblockperlevel: float
    attackrange: float
    hpregen: float
    hpregenperlevel: float
    mpregen: float
    mpregenperlevel: float
    crit: float
    critperlevel: float
    attackdamage: float
    attackdamageperlevel: float
    attackspeed: float
    attackspeedperlevel: float


class Price(BaseModel):
    currency: str
    cost: float


class Sale(BaseModel):
    currency: str
    cost: float
    discount_rate: float
    started_at: str
    ended_at: str


class Skin(BaseModel):
    id: float
    champion_id: float
    name: str
    has_chromas: bool
    splash_image: str
    loading_image: str
    tiles_image: str
    centered_image: str
    skin_video_url: Optional[str] = None
    prices: Optional[list[Price]] = None
    sales: Optional[list[Sale]] = None
    release_date: Optional[str] = None


class Passive(BaseModel):
    name: str
    description: str
    image_url: str
    video_url: Optional[str] = None


class Spell(BaseModel):
    key: str
    name: str
    description: str
    max_rank: float
    range_burn: list[float]
    cooldown_burn: list[float]
    cooldown_burn_float: list[float]
    cost_burn: list[float]
    tooltip: str
    image_url: str
    video_url: Optional[str] = None


class Champion(BaseModel):
    id: int
    key: str
    name: str
    image_url: str
    evolve: list[EvolveItem]
    blurb: str
    title: str
    tags: list[str]
    lore: str
    partype: str
    info: Info
    stats: Stats
    enemy_tips: list[str]
    ally_tips: list[str]
    skins: list[Skin]
    passive: Passive
    spells: list[Spell]


class ChampionAPIResponce(BaseResponse):
    data: list[Champion]




import pytest

from clients.meta_client import OPGGMetaClient
from models.meta_responses import (
    GameTypeAPIResponse,
    SeasonAPIResponce,
    TierAPIResponse,
)
from models.shared import GameType, Season, Tier


@pytest.fixture
def client():
    return OPGGMetaClient()


def test_get_season_enum_matches_api(client: OPGGMetaClient):
    result = client.get_seasons()
    assert isinstance(result, SeasonAPIResponce)

    enum_values = {s.value for s in Season}
    api_ids = {
        r.id for r in result.data}
    
    assert api_ids == enum_values, f"Mismatch! API: {api_ids}, Enum: {enum_values}"


def test_get_tier_enum_matches_api(client: OPGGMetaClient):
    result = client.get_tiers()
    assert isinstance(result, TierAPIResponse)

    enum_values = {t.value for t in Tier}
    api_names = {r.name for r in result.data}

    assert api_names == enum_values, f"Mismatch! API: {api_names}, Enum: {enum_values}"


def test_get_game_type_enum_matches_api(client: OPGGMetaClient):
    result = client.get_game_types()
    assert isinstance(result, GameTypeAPIResponse)

    enum_values = {g.value for g in GameType}
    api_game_types = {r.game_type for r in result.data}

    assert (
        api_game_types == enum_values
    ), f"Mismatch! API: {api_game_types}, Enum: {enum_values}"



import datetime
import urllib
from typing import Generator

from clients.base_client import BaseAPIClient
from models.champion import ChampionAPIResponce
from models.match_history import MatchHistoryAPIResponce
from models.shared import Region
from models.summoner_champion_stats import (
    SummonerChampStatsAPIEmptyResponce,
    SummonerChampStatsAPIResponce,
)


class OPGGClient(BaseAPIClient):
    def __init__(self, region: Region = Region.EUW) -> None:
        super().__init__(base_url="https://lol-web-api.op.gg/api/v1.0/internal/bypass/")
        self.region: Region = region

    def get_match_history(
        self,
        summoner_id: str,
        ended_at: datetime = None,
    ) -> MatchHistoryAPIResponce:
        endpoint = f"games/{self.region.value}/summoners/{summoner_id}"
        params = {
            "limit": 20,
            "hl": "en_US",
            "game_type": "soloranked",
        }
        if ended_at:
            params["ended_at"] = str(ended_at)

        return MatchHistoryAPIResponce(**self._get(endpoint, params).json())

    def get_summoner_details(self):
        return

    def get_champ_stats(
        self,
        summoner_id: str,
        season_id: int = None,
    ) -> SummonerChampStatsAPIResponce | SummonerChampStatsAPIEmptyResponce:
        endpoint = f"summoners/{self.region.value}/{summoner_id}/most-champions/rank"
        params = {
            "game_type": "SOLORANKED",
        }
        if season_id:
            params["season_id"] = season_id
        data = self._get(endpoint, params).json()

        # the api returns data as a list insted of an object when no data is present (fuck opgg)
        if isinstance(data["data"], list):
            return SummonerChampStatsAPIEmptyResponce(**data)

        return SummonerChampStatsAPIResponce(**data)

    def get_all_match_history(
        self,
        summoner_id: str,
        start_date: datetime = None,
    ) -> Generator[MatchHistoryAPIResponce, None, None]:

        responce = self.get_match_history(
            summoner_id=summoner_id,
            ended_at=start_date,
        )
        while len(responce.data) > 0:
            self.logger.info(
                f"Yielding response of type: {type(responce)}"
            )  # Check the type here

            yield responce

            last_game_played = responce
            responce = self.get_match_history(
                summoner_id=summoner_id,
                ended_at=last_game_played.meta.last_game_created_at,
            )

    def get_champion_metadata(self) -> ChampionAPIResponce:
        endpoint = f"meta/champions"
        params = {"hl": "en_US"}

        return ChampionAPIResponce(**self._get(endpoint, params).json())



import logging
from typing import Any, Dict, Optional

import requests
from requests.exceptions import ConnectionError, HTTPError, RequestException, Timeout


class BaseAPIClient:
    """A base class for making GET requests to an API."""

    DEFAULT_TIMEOUT = 10

    def __init__(
        self,
        base_url: str,
        headers: Optional[Dict[str, str]] = None,
        timeout: Optional[int] = DEFAULT_TIMEOUT,
    ) -> None:
        """
        Initialize the API client.

        Args:
            base_url (str): The base URL for the API.
            headers (Optional[Dict[str, str]]): Optional HTTP headers to include in requests.
            timeout (Optional[int]): Request timeout in seconds.
        """
        self.base_url = base_url.rstrip("/")
        self.session = requests.Session()
        self.timeout = timeout
        self.logger = logging.getLogger(self.__class__.__name__)

        if headers:
            self.session.headers.update(headers)

    def _get(
        self,
        endpoint: str,
        params: Optional[Dict[str, Any]] = None,
        headers: Optional[Dict[str, Any]] = None,
        cookies: Optional[Dict[str, Any]] = None,
    ) -> requests.Response:
        """
        Perform a GET request to the given endpoint.

        Args:
            endpoint (str): The API endpoint to call (without the base URL).
            params (Optional[Dict[str, Any]]): Query parameters to include in the request.

        Returns:
            Any: Parsed JSON response.

        Raises:
            HTTPError: If the request fails due to an HTTP error.
            RequestException: For other request-related issues.
        """
        url = f"{self.base_url}/{endpoint.lstrip('/')}"
        try:
            response = self.session.get(
                url,
                params=params,
                headers=headers,
                timeout=self.timeout,
                cookies=cookies,
            )
            print(response.url)
            response.raise_for_status()
            return response
        except Timeout:
            self.logger.error(f"Request timed out: {url}")
            raise
        except ConnectionError:
            self.logger.error(f"Connection error: {url}")
            raise
        except HTTPError as http_err:
            self.logger.error(http_err)
            raise
        except RequestException as req_err:
            self.logger.error(f"Request failed for {url}: {req_err}")
            raise

    def close(self) -> None:
        """Close the session to free up resources."""
        self.session.close()
        self.logger.info("Session closed.")

    def __enter__(self):
        return self

    def __exit__(self, exc_type, exc_value, traceback):
        self.close()
        if exc_type:
            self.logger.error(f"Exception occoured {exc_value}")
        return False



import json
from enum import Enum
from pathlib import Path
from unittest.mock import MagicMock, patch

import pytest

from clients.client import OPGGClient
from models.base_model import BaseResponse
from models.champion import ChampionAPIResponce
from models.match_history import MatchHistoryAPIResponce
from models.shared import Region
from models.summoner_champion_stats import (
    SummonerChampStatsAPIEmptyResponce,
    SummonerChampStatsAPIResponce,
)


class DataPaths(Enum):
    DIR = Path("test_data")
    MATCH_HISTORY = Path("match_history")
    CHAMP_STATS = Path("champ_stats")
    CHAMP_STATS_EMPTY = Path("champ_stats_empty")
    CHAMPION_METADATA = Path("champion_metadata")


JSON_EXTENTION = ".json"
TEST_SUMMONER_ID = "r5WSLNaMXFIpGO-vdtQCHzPjGBTMQB-7JkMjHkpsgdT3qJg"  # challenger player at time of writing 19/03/2025, has no games played in season 1


@pytest.fixture
def client():
    return OPGGClient(region=Region.EUW)


def load_json_test_data(filename: DataPaths, model: BaseResponse) -> BaseResponse:
    """Helper function to load JSON test data."""
    test_data_path = Path(__file__).parent / DataPaths.DIR.value / filename
    with open(
        test_data_path.with_suffix(JSON_EXTENTION), "r", encoding="utf-8"
    ) as file:
        return model(**json.load(file))


def save_json_test_data(filename: DataPaths, data: BaseResponse) -> dict:
    """Helper function to load JSON test data."""
    test_data_path = (
        Path(__file__).parent / "tests" / DataPaths.DIR.value / filename.value
    )
    with open(
        test_data_path.with_suffix(JSON_EXTENTION), "w", encoding="utf-8"
    ) as file:
        file.write(data.model_dump_json())


def test_get_match_history(client: OPGGClient):
    result = client.get_match_history(TEST_SUMMONER_ID)
    assert isinstance(result, MatchHistoryAPIResponce)


def test_opgg_api_health(client: OPGGClient):
    """Test the health of the OPGG API using champion metadata as no params are needed."""
    result = client.get_champion_metadata()
    assert isinstance(result, ChampionAPIResponce)


def test_get_champ_stats(client: OPGGClient):
    result = client.get_champ_stats(TEST_SUMMONER_ID)
    assert isinstance(result, SummonerChampStatsAPIResponce)


def test_get_champ_stats_empty(client: OPGGClient):
    result = client.get_champ_stats(TEST_SUMMONER_ID, 1)
    print(type(result))
    assert isinstance(result, SummonerChampStatsAPIEmptyResponce)


def test_get_champion_metadata(client: OPGGClient):
    result = client.get_champion_metadata()
    assert isinstance(result, ChampionAPIResponce)


@patch("clients.client.OPGGClient.get_match_history")
def test_get_all_match_history(mock_get: MagicMock, client: OPGGClient):

    first_response = load_json_test_data(
        DataPaths.MATCH_HISTORY.value / "2025-03-18", MatchHistoryAPIResponce
    )
    second_response = load_json_test_data(
        DataPaths.MATCH_HISTORY.value / "2025-03-16", MatchHistoryAPIResponce
    )

    end_response = load_json_test_data(
        DataPaths.MATCH_HISTORY.value / "end", MatchHistoryAPIResponce
    )

    mock_get.side_effect = [
        first_response,
        second_response,
        end_response,
    ]

    all_history = list(client.get_all_match_history(TEST_SUMMONER_ID))

    assert len(all_history) == 2
    assert len(all_history[0].data) == len(first_response.data)
    assert len(all_history[1].data) == len(second_response.data)

    assert all_history[0].data[0] == first_response.data[0]
    assert all_history[0].data[1] == first_response.data[1]

    assert all_history[1].data[0] == second_response.data[0]
    assert all_history[1].data[1] == second_response.data[1]



from enum import Enum


class Result(Enum):
    """
    Enum for game results.

    ### Options:
        `WIN` - Represents a win.\n
        `LOSE` - Represents a loss.\n
        `UNKNOWN` - Represents an unknown result.
    """

    WIN = "WIN"
    LOSE = "LOSE"
    UNKNOWN = "UNKNOWN"


class Map(Enum):
    """
    Enum for map types.

    ### Options:
        `SUMMONERS_RIFT` - Summoner's Rift.\n
        `TWISTED_TREELINE` - Twisted Treeline.\n
        `HOWLING_ABYSS` - Howling Abyss.\n
        `CRYSTAL_SCAR` - Crystal Scar.\n
        `BUTCHERS_BRIDGE` - Butcher's Bridge.
    """

    SUMMONERS_RIFT = "SUMMONER'S RIFT"
    TWISTED_TREELINE = "TWISTED TREELINE"
    HOWLING_ABYSS = "HOWLING ABYSS"
    CRYSTAL_SCAR = "CRYSTAL SCAR"
    BUTCHERS_BRIDGE = "BUTCHER'S BRIDGE"


class Key(Enum):
    """
    Enum for team keys.

    ### Options:
        `BLUE` - Represents the blue team.\n
        `RED` - Represents the red team.
    """

    BLUE = "BLUE"
    RED = "RED"


class Tier(Enum):
    """
    Enum for ranked tiers.

    ### Options:
        `IRON` - Iron tier.\n
        `BRONZE` - Bronze tier.\n
        `SILVER` - Silver tier.\n
        `GOLD` - Gold tier.\n
        `PLATINUM` - Platinum tier.\n
        `EMERALD` - Emerald tier.\n
        `DIAMOND` - Diamond tier.\n
        `MASTER` - Master tier.\n
        `GRANDMASTER` - Grandmaster tier.\n
        `CHALLENGER` - Challenger tier.
    """

    IRON = "IRON"
    BRONZE = "BRONZE"
    SILVER = "SILVER"
    GOLD = "GOLD"
    PLATINUM = "PLATINUM"
    EMERALD = "EMERALD"
    DIAMOND = "DIAMOND"
    MASTER = "MASTER"
    GRANDMASTER = "GRANDMASTER"
    CHALLENGER = "CHALLENGER"


class Position(Enum):
    """
    Enum for player positions.

    ### Options:
        `MID` - Mid lane.\n
        `JUNGLE` - Jungle.\n
        `ADC` - Attack Damage Carry (Bot lane).\n
        `TOP` - Top lane.\n
        `SUPPORT` - Support role.
    """

    MID = "MID"
    JUNGLE = "JUNGLE"
    ADC = "ADC"
    TOP = "TOP"
    SUPPORT = "SUPPORT"


class Role(Enum):
    """
    Enum for champion roles.

    ### Options:
        `FIGHTER` - Fighter role.\n
        `MARKSMAN` - Marksman role.\n
        `MAGE` - Mage role.\n
        `TANK` - Tank role.\n
        `CONTROLLER` - Controller role.\n
        `SLAYER` - Slayer role.\n
        `SPECIALIST` - Specialist role.\n
        `NONE` - No specific role.
    """

    FIGHTER = "FIGHTER"
    MARKSMAN = "MARKSMAN"
    MAGE = "MAGE"
    TANK = "TANK"
    CONTROLLER = "CONTROLLER"
    SLAYER = "SLAYER"
    SPECIALIST = "SPECIALIST"
    NONE = "NONE"


class Season(Enum):
    """
    Enum for game seasons.

    ### Options:
        `S1` - Season 1.\n
        `S2` - Season 2.\n
        `S3` - Season 3.\n
        `S4` - Season 4.\n
        `S5` - Season 5.\n
        `S6` - Season 6.\n
        `S7` - Season 7.\n
        `S8_PRESEASON` - Preseason 8.\n
        `S8` - Season 8.\n
        `S9_PRESEASON` - Preseason 9.\n
        `S9` - Season 9.\n
        `S10_PRESEASON` - Preseason 10.\n
        `S10` - Season 10.\n
        `S11_PRESEASON` - Preseason 11.\n
        `S11` - Season 11.\n
        `S12_PRESEASON` - Preseason 12.\n
        `S12` - Season 12.\n
        `S13_SPLIT_1_PRESEASON` - Preseason 13 Split 1.\n
        `S13_SPLIT_1` - Season 13 Split 1.\n
        `S13_SPLIT_2_PRESEASON` - Preseason 13 Split 2.\n
        `S13_SPLIT_2` - Season 13 Split 2.\n
        `S14_SPLIT_1_PRESEASON` - Preseason 14 Split 1.\n
        `S14_SPLIT_1` - Season 14 Split 1.\n
        `S14_SPLIT_2_PRESEASON` - Preseason 14 Split 2.\n
        `S14_SPLIT_2` - Season 14 Split 2.\n
        `S14_SPLIT_3_PRESEASON` - Preseason 14 Split 3.\n
        `S14_SPLIT_3` - Season 14 Split 3.\n
        `S15_PRESEASON` - Preseason 15.\n
        `S15_SEASON_1` - Season 15.
    """

    S1 = 1
    S2 = 2
    S3 = 3
    S4 = 4
    S5 = 5
    S6 = 6
    S7 = 7
    S8_PRESEASON = 10
    S8 = 11
    S9_PRESEASON = 12
    S9 = 13
    S10_PRESEASON = 14
    S10 = 15
    S11_PRESEASON = 16
    S11 = 17
    S12_PRESEASON = 18
    S12 = 19
    S13_SPLIT_1_PRESEASON = 20
    S13_SPLIT_1 = 21
    S13_SPLIT_2_PRESEASON = 22
    S13_SPLIT_2 = 23
    S14_SPLIT_1_PRESEASON = 24
    S14_SPLIT_1 = 25
    S14_SPLIT_2_PRESEASON = 26
    S14_SPLIT_2 = 27
    S14_SPLIT_3_PRESEASON = 28
    S14_SPLIT_3 = 29
    S15_PRESEASON = 30
    S15_SEASON_1 = 31


class GameType(Enum):
    """
    Enum for game types.

    ### Options:
        `TOTAL` - All game types.\n
        `RANKED` - Ranked games.\n
        `SOLORANKED` - Solo ranked games.\n
        `FLEXRANKED` - Flex ranked games.\n
        `NORMAL` - Normal games.\n
        `ARAM` - ARAM games.\n
        `BOT` - Bot games.\n
        `URF` - Ultra Rapid Fire games.\n
        `CLASH` - Clash games.\n
        `ARENA` - Arena games.\n
        `NEXUS_BLITZ` - Nexus Blitz games.\n
        `CUSTOM` - Custom games.\n
        `TUTORIAL` - Tutorial games.\n
        `EVENT` - Event games.
    """

    TOTAL = "TOTAL"
    RANKED = "RANKED"
    SOLORANKED = "SOLORANKED"
    FLEXRANKED = "FLEXRANKED"
    NORMAL = "NORMAL"
    ARAM = "ARAM"
    BOT = "BOT"
    URF = "URF"
    CLASH = "CLASH"
    ARENA = "ARENA"
    NEXUS_BLITZ = "NEXUS_BLITZ"
    CUSTOM = "CUSTOM"
    TUTORIAL = "TUTORIAL"
    EVENT = "EVENT"


class Region(Enum):
    """
    Enum for regions.

    ### Options:
        `NA` - North America\n
        `EUW` - Europe West\n
        `EUNE` - Europe Nordic & East\n
        `KR` - Korea\n
        `JP` - Japan\n
        `BR` - Brazil\n
        `LAN` - Latin America North\n
        `LAS` - Latin America South\n
        `OCE` - Oceania\n
        `RU` - Russia\n
        `TR` - Turkey\n
        `ANY` - Any
    """

    NA = "NA"
    EUW = "EUW"
    EUNE = "EUNE"
    KR = "KR"
    JP = "JP"
    BR = "BR"
    LAN = "LAN"
    LAS = "LAS"
    OCE = "OCE"
    RU = "RU"
    TR = "TR"
    ANY = "ANY"

    def __str__(self):
        return self.value


class By(Enum):
    """
    Enum for search-by or match-by types.

    ### Options:
        `ID` - Generic ID\n
        `KEY` - Generic Key\n
        `NAME` - Generic Name\n
        `COST` - Generic Cost\n
        `BLUE_ESSENCE` - Specific Cost (Blue Essence)\n
        `RIOT_POINTS` - Specific Cost (Riot Points)
    """

    ID = "id"
    NAME = "name"
    COST = "cost"
    BLUE_ESSENCE = "BE"
    RIOT_POINTS = "RP"

    def __str__(self):
        return self.value


class Queue(Enum):
    """
    Enum for queue types.

    ### Options:
        `SOLO` - SoloQueue\n
        `FLEX` - FlexQueue\n
        `ARENA` - Arena
    """

    SOLO = "SOLORANKED"
    FLEX = "FLEXRANKED"
    ARENA = "ARENA"

    def __str__(self):
        return self.value


class LangCode(Enum):
    """
    Enum for language codes.

    Please note, some languages may not be supported by OPGG.

    ---

    ### Options:
        `ENGLISH` - en_US (United States)\n
        `SPANISH` - es_ES (Spain)\n
        `PORTUGUESE` - pt_BR (Brazil)\n
        `FRENCH` - fr_FR (France)\n
        `GERMAN` - de_DE (Germany)\n
        `ITALIAN` - it_IT (Italy)\n
        `RUSSIAN` - ru_RU (Russia)\n
        `TURKISH` - tr_TR (Turkey)\n
        `KOREAN` - ko_KR (Korea)\n
        `JAPANESE` - ja_JP (Japan)\n
        `CHINESE` - zh_CN (Simplified)\n
        `CHINESE_TRAD` - zh_TW (Traditional)
    """

    ENGLISH = "en_US"  # English (United States)
    SPANISH = "es_ES"  # Spanish (Spain)
    PORTUGUESE = "pt_BR"  # Portuguese (Brazil)
    FRENCH = "fr_FR"  # French (France)
    GERMAN = "de_DE"  # German (Germany)
    ITALIAN = "it_IT"  # Italian (Italy)
    RUSSIAN = "ru_RU"  # Russian (Russia)
    TURKISH = "tr_TR"  # Turkish (Turkey)
    KOREAN = "ko_KR"  # Korean (Korea)
    JAPANESE = "ja_JP"  # Japanese (Japan)
    CHINESE = "zh_CN"  # Chinese (Simplified)
    CHINESE_TRAD = "zh_TW"  # Chinese (Traditional)

    def __str__(self):
        return self.value



from setuptools import find_packages, setup

setup(
    name="opgg-client", 
    version="0.1.0", 
    author="dwwescalelol", 
    author_email="james.abdallah@gmail.com", 
    description="A Python client for interacting with the OPGG API.",
    long_description=open("README.md", "r", encoding="utf-8").read(),
    long_description_content_type="text/markdown",
    url="https://github.com/dwwescalelol/opgg-client",
    packages=find_packages(exclude=["tests*", "test_data*"]),
    include_package_data=True,
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires=">=3.10",
    install_requires=[
        "requests>=2.25.1",
        "pydantic>=1.10.0",
    ],
    extras_require={
        "dev": [
            "pytest>=7.0.0",
            "pytest-mock>=3.10.0",
        ],
    },
    entry_points={
        "console_scripts": [
            "opgg-client=main:main",
        ],
    },
)



from datetime import datetime
from enum import Enum
from typing import Any, Optional

from pydantic import AnyUrl, BaseModel

from models.base_model import BaseResponse
from models.shared import Key, Position, Result, Role, Tier


class Rune(BaseModel):
    primary_page_id: int
    primary_rune_id: int
    secondary_page_id: int


class ChampionTemp(BaseModel):
    id: int
    key: str


class OpScoreTimeline(BaseModel):
    second: int
    score: float


class Summoner(BaseModel):
    id: int
    summoner_id: str
    acct_id: str
    puuid: str
    game_name: str
    tagline: str
    name: str
    internal_name: str
    profile_image_url: AnyUrl
    level: int
    updated_at: datetime
    renewable_at: datetime
    revision_at: Optional[datetime]
    player: Optional[Any]


class QueueInfo(BaseModel):
    id: int
    queue_translate: str
    game_type: str


class GameStat(BaseModel):
    is_win: bool
    champion_kill: int
    champion_first: bool
    inhibitor_kill: int
    inhibitor_first: bool
    rift_herald_kill: int
    rift_herald_first: bool
    dragon_kill: int
    dragon_first: bool
    baron_kill: int
    baron_first: bool
    tower_kill: int
    tower_first: bool
    horde_kill: int
    horde_first: bool
    is_remake: bool
    death: int
    assist: int
    gold_earned: int
    kill: int


class Last(Enum):
    EXCELLENT = "EXCELLENT"
    GOOD = "GOOD"
    FAIR = "FAIR"
    POOR = "POOR"


class Left(Enum):
    DOWN = "DOWN"
    UP = "UP"


class AverageTierInfo(BaseModel):
    tier: Tier
    division: int
    tier_image_url: AnyUrl
    border_image_url: AnyUrl


class OpScoreTimelineAnalysis(BaseModel):
    left: Left
    right: Left
    last: Last


class TierInfo(BaseModel):
    tier: Optional[Tier]
    division: Optional[int]
    lp: Optional[int]
    level: Optional[int]
    tier_image_url: AnyUrl
    border_image_url: Optional[AnyUrl]


class Team(BaseModel):
    key: Key
    game_stat: GameStat
    banned_champions: list[Optional[int]]


class Stats(BaseModel):
    champion_level: int
    damage_self_mitigated: int
    damage_dealt_to_objectives: int
    damage_dealt_to_turrets: int
    magic_damage_dealt_player: int
    physical_damage_taken: int
    physical_damage_dealt_to_champions: int
    total_damage_taken: int
    total_damage_dealt: int
    total_damage_dealt_to_champions: int
    largest_critical_strike: int
    time_ccing_others: int
    vision_score: int
    vision_wards_bought_in_game: int
    sight_wards_bought_in_game: int
    ward_kill: int
    ward_place: int
    turret_kill: int
    barrack_kill: int
    kill: int
    death: int
    assist: int
    largest_multi_kill: int
    largest_killing_spree: int
    minion_kill: int
    neutral_minion_kill_team_jungle: None
    neutral_minion_kill_enemy_jungle: None
    neutral_minion_kill: int
    gold_earned: int
    total_heal: int
    result: Result
    op_score: float
    op_score_rank: int
    is_opscore_max_in_team: bool
    lane_score: Optional[int]
    op_score_timeline: list[OpScoreTimeline]
    op_score_timeline_analysis: Optional[OpScoreTimelineAnalysis]
    keyword: Optional[str]
    keyword_label_temp: Optional[str] = None
    keyword_desc_temp: Optional[str] = None
    champion_temp: Optional[ChampionTemp] = None


class MyData(BaseModel):
    summoner: Summoner
    participant_id: int
    champion_id: int
    team_key: Key
    position: Position
    role: Optional[Role]
    items: list[int]
    trinket_item: int
    rune: Rune
    spells: list[int]
    stats: Stats
    tier_info: TierInfo


class Game(BaseModel):
    id: str
    created_at: datetime
    game_map: str
    queue_info: Optional[QueueInfo] = None
    game_type: str
    version: str
    meta_version: str
    game_length_second: int
    is_remake: bool
    is_opscore_active: bool
    is_recorded: Optional[bool]
    record_info: Any
    average_tier_info: AverageTierInfo
    participants: list[MyData]
    teams: list[Team]
    memo: Any
    myData: MyData


class Meta(BaseModel):
    first_game_created_at: Optional[datetime]
    last_game_created_at: Optional[datetime]


class MatchHistoryAPIResponce(BaseResponse):
    data: Optional[list[Game]] = []
    meta: Meta



from typing import Optional

from pydantic import BaseModel


class ChampionStat(BaseModel):
    id: int
    play: int
    win: int
    lose: int
    game_length_second: Optional[int] = None
    kill: int
    death: int
    assist: int
    gold_earned: int
    minion_kill: int
    neutral_minion_kill: int
    damage_taken: int
    damage_dealt_to_champions: Optional[int]
    double_kill: int
    triple_kill: int
    quadra_kill: int
    penta_kill: int
    vision_wards_bought_in_game: Optional[int]
    op_score: Optional[int]
    snowball_throws: Optional[int]
    snowball_hits: Optional[int]


class Data(BaseModel):
    game_type: str
    season_id: int
    year: Optional[int]
    play: int
    win: int
    lose: int
    champion_stats: list[ChampionStat]


class SummonerChampStatsAPIResponce(BaseModel):
    data: Data


class SummonerChampStatsAPIEmptyResponce(BaseModel):
    data: list[None]



from typing import Optional

from pydantic import BaseModel

from models.base_model import BaseResponse


class SeasonModel(BaseModel):
    id: int
    value: int
    display_value: int
    split: Optional[int] = None
    is_preseason: bool


class SeasonAPIResponce(BaseResponse):
    data: list[SeasonModel]


class GameTypeModel(BaseModel):
    game_type: str
    game_translate: str


class GameTypeAPIResponse(BaseResponse):
    data: list[GameTypeModel]


class TierModel(BaseModel):
    name: str
    tier_image_url: str
    border_image_url: str
    tier_mini_image_url: str


class TierAPIResponse(BaseResponse):
    data: list[TierModel]
